@@ -8,13 +8,13 @@
 ## Open Project & Edges Extraction
 ## ===============================
 
-##' This function import and format the data from a coding tool in a Qualitatve Data Analysis.
+##' This function import and format the data from a coding tool in a Qualitative Data Analysis.
 ##'
-##'This function import and format the data from a coding tool in a Qualitatve Data Analysis (QDA).
-##' @title Import a Qualitatve Data Analysis project
+##'This function import and format the data from a coding tool in a Qualitative Data Analysis (QDA).
+##' @title Import a Qualitative Data Analysis project
 ##' @param main_path The main to your QDA project. It must ended with '/'
 ##' @param project_name The name of your project (as defined in 'qcoder', the name of the subfolder in your main_path). This name is also used in some filenames in the data_frame subsubfolders.
-##' @param coder A character string indicating the coding tool used for coding the QDA. The only tool supported now is 'qcoder'. Earlier version of cogmapr worked with "RQDA" project (no more maintened).
+##' @param coder A character string indicating the coding tool used for coding the QDA. The only tool supported now is 'qcoder'. Earlier version of cogmapr worked with "RQDA" project (no more maintained).
 ##' @param sep (==Depreciated, with RQDA project==) A character string (often a single character) that is used in RQDA in order to express the relationships between two variables. Default is "_" if codes used in RQDA are of the form : "x_y" (\emph{i.e.} relationship from x to y), but it is possible to use ">", "->", "-->" or even "--->"
 ##' @examples
 ##' project_name <- "a_new_project"
@@ -67,11 +67,11 @@ ProjectCMap <- function(main_path, project_name, coder = "qcoder", sep = ">"){
 ##'
 ##' This function opens a Qualitative Data Analysis (QDA) project and extracts edge information.
 ##'
-##' The coding used in the QDA have to be done using the 'cogamp-dev' branch of the qcoder package (github : 'FrdVnW/qcoder'). devtools::install_github('FrdVnW/qcoder', ref = "cogmap-dev", upgrade = 'never')
+##' The coding used in the QDA have to be done using the 'cogmap-dev' branch of the qcoder package (github : 'FrdVnW/qcoder'). devtools::install_github('FrdVnW/qcoder', ref = "cogmap-dev", upgrade = 'never')
 ##' 
 ##' @param project A QDA project, a list as generated by the ProjectCMap function.
 ##' @inheritParams ProjectCMap
-##' @return A data.frame with the relationships identified in the interviews. Each relationships ('coding_id') is linked to an agent ('doc_ed'), an edge's name ('edge'), the varible at the origin of the relationships ('concept_from'), the variable at the end of the relationships ('concept_to'), other properties of the relationships ('coding_sign', 'coding_weight', 'coding_class' and 'document_part') and the quotes linked to relationships ('selected_text').
+##' @return A data.frame with the relationships identified in the interviews. Each relationships ('coding_id') is linked to an agent ('doc_id'), an edge's name ('edge'), the variable at the origin of the relationships ('concept_from'), the variable at the end of the relationships ('concept_to'), other properties of the relationships ('coding_sign', 'coding_weight', 'coding_class' and 'document_part') and the quotes linked to relationships ('selected_text').
 ##' @examples
 ##' project_name <- "a_new_project"
 ##' main_path <- paste0(system.file("testdata", package = "cogmapr"), '/')
@@ -102,7 +102,7 @@ EdgCMap <- function(project, sep = ">", coder = "qcoder") {
 ##'
 ##' This function opens a Qualitative Data Analysis (QDA) project and extracts edge information for individual cognitive mapping
 ##'
-##' The coding used in the QDA have to be done using the 'cogamp-dev' branch of the qcoder package (github : 'FrdVnW/qcoder'). devtools::install_github('FrdVnW/qcoder', ref = "cogmap-dev", upgrade = 'never')
+##' The coding used in the QDA have to be done using the 'cogmap-dev' branch of the qcoder package (github : 'FrdVnW/qcoder'). devtools::install_github('FrdVnW/qcoder', ref = "cogmap-dev", upgrade = 'never')
 ##' 
 ##' @inheritParams EdgCMap
 ##' @param min.weight A integer that will determine the minimum (>=) weight of relationships that will be taken into account. Relationships with a lower weight (<) will not be shown. Default is set to 1 (\emph{i.e.} all relationships are shown).
@@ -354,9 +354,9 @@ EdgSocCMap <- function(project, min.weight = 1, filters = NULL, units = 'all', w
 ##' @param data.edges.soc A data.frame as produced by the EdgSocCMap function
 ##' @inheritParams EdgSocCMap
 ##' @param label A character string that defines the text that will be print in the variables (vertex) of the cognitive maps. It can be "num", "name" or "numname" (which is of the form "NUM - Name"). The default is "num"
-##' @param minlen A graphical parameter that defines a relative lenght between the variable of the cognitive maps. See help from RGraphViz package.
+##' @param minlen A graphical parameter that defines a relative length between the variable of the cognitive maps. See help from RGraphViz package.
 ##' @param fontsize The fontsize of vertices (concepts), in r-base plot
-##' @param shape The shape of the verices (concepts), in r-base plot
+##' @param shape The shape of the vertices (concepts), in r-base plot
 ##' @return a 'SocCMap' object, a list containing various information that could be use for plotting an Individual Cognitive Map. The most important elements are :
 ##' \describe{
 ##' \item{"vertex"}{A list of information on Cognitive Map's variables (i.e. vertices)}
@@ -618,7 +618,7 @@ ggCMap <- function(data,
         + geom_point(aes(x, y, color = concept.class),
                      size = size.concepts, data = data.vertex.soc) # , size=degree
         + geom_segment(aes(x = x.from , y = y.from,
-                                  xend = x.to, yend = y.to, size = coding_weight),
+                                  xend = x.to, yend = y.to, linewidth = coding_weight),
                        arrow = arrow(angle = 15, length = unit((size.arrows/5), "inches"),
                                      type = "closed"),
                        data = data.edges.soc, colour = "black", alpha = alpha.arrows,
@@ -683,7 +683,7 @@ ggCMap.bg <- function(data,
                      size = size.concepts, data = data.vertex.soc,
                      colour = map.color) # , size=degree
         + geom_segment(aes(x = x.from , y = y.from,
-                                  xend = x.to, yend = y.to, size = coding_weight),
+                                  xend = x.to, yend = y.to, linewidth = coding_weight),
                        arrow = grid::arrow(angle = 15, length = unit((size.arrows/5), "inches"),
                                      type = "closed"),
                        data = data.edges.soc,
@@ -768,7 +768,7 @@ ggCMap.hl <- function(project, min.weight = 1,
             + geom_point(aes(x, y, color = concept.class),
                          size = size.concepts, data = data.vertex.soc) # , size=degree
             + geom_segment(aes(x = x.from , y = y.from,
-                               xend = x.to, yend = y.to, size = coding_weight),
+                               xend = x.to, yend = y.to, linewidth = coding_weight),
                            arrow = arrow(angle = 15, length = unit((size.arrows/5), "inches"),
                                          type = "closed"),
                            data = data.edges.soc, colour = "black", alpha = alpha.arrows,
